@@ -46,19 +46,19 @@ impl fmt::Display for RankedBy {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
         match *self {
             RankedBy::MatchWins => {
-                try!(fmt.write_str("match wins"));
+                fmt.write_str("match wins")?;
             }
             RankedBy::GameWins => {
-                try!(fmt.write_str("game wins"));
+                fmt.write_str("game wins")?;
             }
             RankedBy::PointsScored => {
-                try!(fmt.write_str("points scored"));
+                fmt.write_str("points scored")?;
             }
             RankedBy::PointsDifference => {
-                try!(fmt.write_str("points difference"));
+                fmt.write_str("points difference")?;
             }
             RankedBy::Custom => {
-                try!(fmt.write_str("custom"));
+                fmt.write_str("custom")?;
             }
         }
         Ok(())
@@ -79,13 +79,13 @@ impl fmt::Display for TournamentId {
         match *self {
             TournamentId::Url(ref subdomain, ref tournament_url) => {
                 if subdomain.is_empty() {
-                    try!(fmt.write_str(tournament_url));
+                    fmt.write_str(tournament_url)?;
                 } else {
-                    try!(fmt.write_str(&format!("{}-{}", subdomain, tournament_url)));
+                    fmt.write_str(&format!("{}-{}", subdomain, tournament_url))?;
                 }
             }
             TournamentId::Id(ref id) => {
-                try!(fmt.write_str(&id.to_string()));
+                fmt.write_str(&id.to_string())?;
             }
         }
         Ok(())
@@ -120,11 +120,11 @@ impl GamePoints {
         bye: Option<f64>,
     ) -> GamePoints {
         GamePoints {
-            match_win: match_win,
-            match_tie: match_tie,
-            game_win: game_win,
-            game_tie: game_tie,
-            bye: bye,
+            match_win,
+            match_tie,
+            game_win,
+            game_tie,
+            bye,
         }
     }
 
@@ -141,31 +141,31 @@ impl GamePoints {
         }
 
         Ok(GamePoints {
-            match_win: try!(remove(&mut map, &format!("{}pts_for_match_win", prefix)))
+            match_win: remove(&mut map, &format!("{}pts_for_match_win", prefix))?
                 .as_string()
                 .unwrap_or("")
                 .to_owned()
                 .parse::<f64>()
                 .unwrap_or(0f64),
-            match_tie: try!(remove(&mut map, &format!("{}pts_for_match_tie", prefix)))
+            match_tie: remove(&mut map, &format!("{}pts_for_match_tie", prefix))?
                 .as_string()
                 .unwrap_or("")
                 .to_owned()
                 .parse::<f64>()
                 .unwrap_or(0f64),
-            game_win: try!(remove(&mut map, &format!("{}pts_for_game_win", prefix)))
+            game_win: remove(&mut map, &format!("{}pts_for_game_win", prefix))?
                 .as_string()
                 .unwrap_or("")
                 .to_owned()
                 .parse::<f64>()
                 .unwrap_or(0f64),
-            game_tie: try!(remove(&mut map, &format!("{}pts_for_game_tie", prefix)))
+            game_tie: remove(&mut map, &format!("{}pts_for_game_tie", prefix))?
                 .as_string()
                 .unwrap_or("")
                 .to_owned()
                 .parse::<f64>()
                 .unwrap_or(0f64),
-            bye: bye,
+            bye,
         })
     }
 }
@@ -299,6 +299,12 @@ impl TournamentCreate {
     builder!(grand_finals_modifier, Option<String>);
 }
 
+impl Default for TournamentCreate {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 /// Challonge `Tournament` definition.
 #[derive(Debug, Clone)]
 pub struct Tournament {
@@ -445,154 +451,140 @@ pub struct Tournament {
 impl Tournament {
     /// Decodes `Tournament` from JSON.
     pub fn decode(value: Value) -> Result<Tournament, Error> {
-        let mut value = try!(into_map(value));
-        let t = try!(remove(&mut value, "tournament"));
-        let mut tv = try!(into_map(t));
+        let mut value = into_map(value)?;
+        let t = remove(&mut value, "tournament")?;
+        let mut tv = into_map(t)?;
 
         let mut started_at = None;
-        if let Some(dt_str) = try!(remove(&mut tv, "started_at")).as_string() {
+        if let Some(dt_str) = remove(&mut tv, "started_at")?.as_string() {
             if let Ok(dt) = DateTime::parse_from_rfc3339(dt_str) {
                 started_at = Some(dt);
             }
         }
 
         Ok(Tournament {
-            accept_attachments: try!(remove(&mut tv, "accept_attachments"))
+            accept_attachments: remove(&mut tv, "accept_attachments")?
                 .as_boolean()
                 .unwrap_or(false),
-            allow_participant_match_reporting: try!(remove(
+            allow_participant_match_reporting: remove(
                 &mut tv,
-                "allow_participant_match_reporting"
-            ))
+                "allow_participant_match_reporting",
+            )?
             .as_boolean()
             .unwrap_or(false),
-            anonymous_voting: try!(remove(&mut tv, "anonymous_voting"))
+            anonymous_voting: remove(&mut tv, "anonymous_voting")?
                 .as_boolean()
                 .unwrap_or(false),
             created_at: DateTime::parse_from_rfc3339(
-                try!(remove(&mut tv, "created_at"))
-                    .as_string()
-                    .unwrap_or(""),
+                remove(&mut tv, "created_at")?.as_string().unwrap_or(""),
             )
             .unwrap(),
-            created_by_api: try!(remove(&mut tv, "created_by_api"))
+            created_by_api: remove(&mut tv, "created_by_api")?
                 .as_boolean()
                 .unwrap_or(false),
-            credit_capped: try!(remove(&mut tv, "credit_capped"))
+            credit_capped: remove(&mut tv, "credit_capped")?
                 .as_boolean()
                 .unwrap_or(false),
-            description: try!(remove(&mut tv, "description"))
+            description: remove(&mut tv, "description")?
                 .as_string()
                 .unwrap_or("")
                 .to_string(),
-            game_id: try!(remove(&mut tv, "game_id")).as_u64().unwrap_or(0),
-            id: TournamentId::Id(try!(remove(&mut tv, "id")).as_u64().unwrap_or(0)),
-            name: try!(remove(&mut tv, "name"))
+            game_id: remove(&mut tv, "game_id")?.as_u64().unwrap_or(0),
+            id: TournamentId::Id(remove(&mut tv, "id")?.as_u64().unwrap_or(0)),
+            name: remove(&mut tv, "name")?
                 .as_string()
                 .unwrap_or("")
                 .to_string(),
-            group_stages_enabled: try!(remove(&mut tv, "group_stages_enabled"))
+            group_stages_enabled: remove(&mut tv, "group_stages_enabled")?
                 .as_boolean()
                 .unwrap_or(false),
-            hide_forum: try!(remove(&mut tv, "hide_forum"))
+            hide_forum: remove(&mut tv, "hide_forum")?.as_boolean().unwrap_or(false),
+            hide_seeds: remove(&mut tv, "hide_seeds")?.as_boolean().unwrap_or(false),
+            hold_third_place_match: remove(&mut tv, "hold_third_place_match")?
                 .as_boolean()
                 .unwrap_or(false),
-            hide_seeds: try!(remove(&mut tv, "hide_seeds"))
-                .as_boolean()
-                .unwrap_or(false),
-            hold_third_place_match: try!(remove(&mut tv, "hold_third_place_match"))
-                .as_boolean()
-                .unwrap_or(false),
-            max_predictions_per_user: try!(remove(&mut tv, "max_predictions_per_user"))
+            max_predictions_per_user: remove(&mut tv, "max_predictions_per_user")?
                 .as_u64()
                 .unwrap_or(0),
-            notify_users_when_matches_open: try!(remove(&mut tv, "notify_users_when_matches_open"))
+            notify_users_when_matches_open: remove(&mut tv, "notify_users_when_matches_open")?
                 .as_boolean()
                 .unwrap_or(false),
-            notify_users_when_the_tournament_ends: try!(remove(
+            notify_users_when_the_tournament_ends: remove(
                 &mut tv,
-                "notify_users_when_the_tournament_ends"
-            ))
+                "notify_users_when_the_tournament_ends",
+            )?
             .as_boolean()
             .unwrap_or(false),
-            open_signup: try!(remove(&mut tv, "open_signup"))
+            open_signup: remove(&mut tv, "open_signup")?
                 .as_boolean()
                 .unwrap_or(false),
-            participants_count: try!(remove(&mut tv, "participants_count"))
-                .as_u64()
-                .unwrap_or(0),
-            prediction_method: try!(remove(&mut tv, "prediction_method"))
-                .as_u64()
-                .unwrap_or(0),
-            private: try!(remove(&mut tv, "private"))
-                .as_boolean()
-                .unwrap_or(false),
-            progress_meter: try!(remove(&mut tv, "progress_meter"))
-                .as_u64()
-                .unwrap_or(0),
+            participants_count: remove(&mut tv, "participants_count")?.as_u64().unwrap_or(0),
+            prediction_method: remove(&mut tv, "prediction_method")?.as_u64().unwrap_or(0),
+            private: remove(&mut tv, "private")?.as_boolean().unwrap_or(false),
+            progress_meter: remove(&mut tv, "progress_meter")?.as_u64().unwrap_or(0),
             swiss_points: GamePoints::decode(&mut tv, "").unwrap(),
-            quick_advance: try!(remove(&mut tv, "quick_advance"))
+            quick_advance: remove(&mut tv, "quick_advance")?
                 .as_boolean()
                 .unwrap_or(false),
-            require_score_agreement: try!(remove(&mut tv, "require_score_agreement"))
+            require_score_agreement: remove(&mut tv, "require_score_agreement")?
                 .as_boolean()
                 .unwrap_or(false),
             round_robin_points: GamePoints::decode(&mut tv, "rr_").unwrap(),
-            sequential_pairings: try!(remove(&mut tv, "sequential_pairings"))
+            sequential_pairings: remove(&mut tv, "sequential_pairings")?
                 .as_boolean()
                 .unwrap_or(false),
-            show_rounds: try!(remove(&mut tv, "show_rounds"))
+            show_rounds: remove(&mut tv, "show_rounds")?
                 .as_boolean()
                 .unwrap_or(false),
-            started_at: started_at,
-            swiss_rounds: try!(remove(&mut tv, "swiss_rounds")).as_u64().unwrap_or(0),
-            teams: try!(remove(&mut tv, "teams")).as_boolean().unwrap_or(false),
+            started_at,
+            swiss_rounds: remove(&mut tv, "swiss_rounds")?.as_u64().unwrap_or(0),
+            teams: remove(&mut tv, "teams")?.as_boolean().unwrap_or(false),
             tournament_type: TournamentType::from_str(
-                try!(remove(&mut tv, "tournament_type"))
+                remove(&mut tv, "tournament_type")?
                     .as_string()
                     .unwrap_or(""),
             )
             .unwrap_or(TournamentType::SingleElimination),
             updated_at: DateTime::parse_from_rfc3339(
-                try!(remove(&mut tv, "updated_at")).as_string().unwrap(),
+                remove(&mut tv, "updated_at")?.as_string().unwrap(),
             )
             .unwrap(),
-            url: try!(remove(&mut tv, "url"))
+            url: remove(&mut tv, "url")?
                 .as_string()
                 .unwrap_or("")
                 .to_string(),
-            description_source: try!(remove(&mut tv, "description_source"))
+            description_source: remove(&mut tv, "description_source")?
                 .as_string()
                 .unwrap_or("")
                 .to_string(),
-            full_challonge_url: try!(remove(&mut tv, "full_challonge_url"))
+            full_challonge_url: remove(&mut tv, "full_challonge_url")?
                 .as_string()
                 .unwrap_or("")
                 .to_string(),
-            live_image_url: try!(remove(&mut tv, "live_image_url"))
+            live_image_url: remove(&mut tv, "live_image_url")?
                 .as_string()
                 .unwrap_or("")
                 .to_string(),
-            review_before_finalizing: try!(remove(&mut tv, "review_before_finalizing"))
+            review_before_finalizing: remove(&mut tv, "review_before_finalizing")?
                 .as_boolean()
                 .unwrap_or(false),
-            accepting_predictions: try!(remove(&mut tv, "accepting_predictions"))
+            accepting_predictions: remove(&mut tv, "accepting_predictions")?
                 .as_boolean()
                 .unwrap_or(false),
-            participants_locked: try!(remove(&mut tv, "participants_locked"))
+            participants_locked: remove(&mut tv, "participants_locked")?
                 .as_boolean()
                 .unwrap_or(false),
-            game_name: try!(remove(&mut tv, "game_name"))
+            game_name: remove(&mut tv, "game_name")?
                 .as_string()
                 .unwrap_or("")
                 .to_string(),
-            participants_swappable: try!(remove(&mut tv, "participants_swappable"))
+            participants_swappable: remove(&mut tv, "participants_swappable")?
                 .as_boolean()
                 .unwrap_or(false),
-            team_convertable: try!(remove(&mut tv, "team_convertable"))
+            team_convertable: remove(&mut tv, "team_convertable")?
                 .as_boolean()
                 .unwrap_or(false),
-            group_stages_were_started: try!(remove(&mut tv, "group_stages_were_started"))
+            group_stages_were_started: remove(&mut tv, "group_stages_were_started")?
                 .as_boolean()
                 .unwrap_or(false),
         })
@@ -605,7 +597,7 @@ pub struct Index(pub Vec<Tournament>);
 impl Index {
     /// Decodes tournament index from JSON.
     pub fn decode(value: Value) -> Result<Index, Error> {
-        Ok(Index(try!(decode_array(value, Tournament::decode))))
+        Ok(Index(decode_array(value, Tournament::decode)?))
     }
 }
 
@@ -638,33 +630,24 @@ impl TournamentType {
 impl fmt::Display for TournamentType {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
         match *self {
-            TournamentType::SingleElimination => {
-                try!(fmt.write_str("single elimination"));
-            }
-            TournamentType::DoubleElimination => {
-                try!(fmt.write_str("double elimination"));
-            }
-            TournamentType::RoundRobin => {
-                try!(fmt.write_str("round robin"));
-            }
-            TournamentType::Swiss => {
-                try!(fmt.write_str("swiss"));
-            }
+            TournamentType::SingleElimination => fmt.write_str("single elimination"),
+            TournamentType::DoubleElimination => fmt.write_str("double elimination"),
+            TournamentType::RoundRobin => fmt.write_str("round robin"),
+            TournamentType::Swiss => fmt.write_str("swiss"),
         }
-        Ok(())
     }
 }
 impl FromStr for TournamentType {
     type Err = ();
     fn from_str(s: &str) -> Result<TournamentType, ()> {
         match s {
-            "single_elimination" => return Ok(TournamentType::SingleElimination),
-            "single elimination" => return Ok(TournamentType::SingleElimination),
-            "double_elimination" => return Ok(TournamentType::DoubleElimination),
-            "double elimination" => return Ok(TournamentType::DoubleElimination),
-            "round_robin" => return Ok(TournamentType::RoundRobin),
-            "round robin" => return Ok(TournamentType::RoundRobin),
-            "swiss" => return Ok(TournamentType::Swiss),
+            "single_elimination" => Ok(TournamentType::SingleElimination),
+            "single elimination" => Ok(TournamentType::SingleElimination),
+            "double_elimination" => Ok(TournamentType::DoubleElimination),
+            "double elimination" => Ok(TournamentType::DoubleElimination),
+            "round_robin" => Ok(TournamentType::RoundRobin),
+            "round robin" => Ok(TournamentType::RoundRobin),
+            "swiss" => Ok(TournamentType::Swiss),
             _ => Err(()),
         }
     }
@@ -689,16 +672,16 @@ impl fmt::Display for TournamentState {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
         match *self {
             TournamentState::All => {
-                try!(fmt.write_str("all"));
+                fmt.write_str("all")?;
             }
             TournamentState::Pending => {
-                try!(fmt.write_str("pending"));
+                fmt.write_str("pending")?;
             }
             TournamentState::InProgress => {
-                try!(fmt.write_str("in_progress"));
+                fmt.write_str("in_progress")?;
             }
             TournamentState::Ended => {
-                try!(fmt.write_str("ended"));
+                fmt.write_str("ended")?;
             }
         }
         Ok(())
